@@ -1,4 +1,4 @@
-function o=meansq(i,DIM)
+function o=meansq(x,DIM)
 % MEANSQ calculates the mean of the squares
 %
 % y = meansq(x,DIM)
@@ -30,21 +30,18 @@ function o=meansq(i,DIM)
 %    along with this program; If not, see <http://www.gnu.org/licenses/>.
 
 
-% original Copyright by:  KH <Kurt.Hornik@ci.tuwien.ac.at>
-%
-%	Copyright (C) 2000-2003 by Alois Schloegl <a.schloegl@ieee.org>	
-%	$Revision: 4585 $
-%	$Id: meansq.m 4585 2008-02-04 13:47:45Z adb014 $
+%	Copyright (C) 2000-2003,2009 by Alois Schloegl <a.schloegl@ieee.org>	
+%	$Id: meansq.m 5603 2009-03-11 10:37:04Z schloegl $
+%       This is part of the NaN-toolbox for Octave and Matlab 
+%       see also: http://hci.tugraz.at/schloegl/matlab/NaN/       
 
 
-x = real(i).^2+imag(i).^2;
-
 if nargin<2,
-	[o,N] = sumskipnan(x);
+	[o,N,ssq] = sumskipnan(x);
 else
-	[o,N] = sumskipnan(x,DIM);
+	[o,N,ssq] = sumskipnan(x,DIM);
 end;
 
-o = o./N;
+o = ssq./N;
 
    
