@@ -1,4 +1,4 @@
-function o=rms(i,DIM)
+function o=rms(x,DIM)
 % RMS calculates the root mean square
 %   can deal with complex data. 
 %
@@ -32,19 +32,18 @@ function o=rms(i,DIM)
 %    along with this program; If not, see <http://www.gnu.org/licenses/>.
 
 
-%	Copyright (C) 2000-2003 by Alois Schloegl <a.schloegl@ieee.org>	
-%	$Revision: 4585 $
-%	$Id: rms.m 4585 2008-02-04 13:47:45Z adb014 $
+%	$Id: rms.m 5607 2009-03-12 16:43:18Z schloegl $
+%	Copyright (C) 2000-2003,2008 by Alois Schloegl <a.schloegl@ieee.org>	
+%       This function is part of the NaN-toolbox
+%       http://www.dpmi.tu-graz.ac.at/~schloegl/matlab/NaN/
 
 
-i = real(i).^2 + imag(i).^2;
-
 if nargin<2,
-	[o,N] = sumskipnan(i);
+	[o,N,ssq] = sumskipnan(x);
 else
-	[o,N] = sumskipnan(i,DIM);
+	[o,N,ssq] = sumskipnan(x,DIM);
 end;
 
-o = sqrt(o./N);
+o = sqrt(ssq./N);
    
    
\ No newline at end of file
